# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API AnimationEffect <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260>`_
"""

APPEAR: 'uno.Enum'
"""
use the animation effect \"Appear\".
"""
CLOCKWISE: 'uno.Enum'
"""
use the animation effect \"Clockwise\".

use the fade effect \"Clockwise\".
"""
CLOSE_HORIZONTAL: 'uno.Enum'
"""
use the animation effect \"Close Horizontal\".

use the fade effect \"Close Horizontal\".
"""
CLOSE_VERTICAL: 'uno.Enum'
"""
use the animation effect \"Close Vertical\".

use the fade effect \"Close Vertical\".
"""
COUNTERCLOCKWISE: 'uno.Enum'
"""
use the animation effect \"Counter Clockwise\".

use the fade effect \"Counter Clockwise\".
"""
DISSOLVE: 'uno.Enum'
"""
use the animation effect \"Spiral Inward Left\".

use the fade effect \"Dissolve\".
"""
FADE_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Fade from Bottom\".

use the fade effect \"Fade from Bottom\".
"""
FADE_FROM_CENTER: 'uno.Enum'
"""
use the animation effect \"Fade from Center\".

use the fade effect \"Fade from Center\".
"""
FADE_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Fade from Left\".

use the fade effect \"Fade from Left\".
"""
FADE_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Fade from Lower Left\".

use the fade effect \"Fade from Lower Left\".
"""
FADE_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Fade from Lower Right\".

use the fade effect \"Fade from Lower Right\".
"""
FADE_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Fade from Right\".

use the fade effect \"Fade from Right\".
"""
FADE_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Fade from Top\".

use the fade effect \"Fade from Top\".
"""
FADE_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Fade from Upper Left\".

use the fade effect \"Fade from Upper Left\".
"""
FADE_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Fade from Upper Right\".

use the fade effect \"Fade from Upper Right\".
"""
FADE_TO_CENTER: 'uno.Enum'
"""
use the animation effect \"Fade to Center\".

use the fade effect \"Fade to Center\".
"""
HIDE: 'uno.Enum'
"""
use the animation effect \"Hide\".
"""
HORIZONTAL_CHECKERBOARD: 'uno.Enum'
"""
use the animation effect \"Horizontal Checkerboard\".

use the fade effect \"Horizontal Checkerboard\".
"""
HORIZONTAL_LINES: 'uno.Enum'
"""
use the animation effect \"Horizontal Lines\".

use the fade effect \"Horizontal Lines\".
"""
HORIZONTAL_ROTATE: 'uno.Enum'
"""
use the animation effect \"Horizontal Rotate\".
"""
HORIZONTAL_STRETCH: 'uno.Enum'
"""
use the animation effect \"Horizontal Stretch\".
"""
HORIZONTAL_STRIPES: 'uno.Enum'
"""
use the animation effect \"Horizontal Stripes\".

use the fade effect \"Horizontal Stripes\".
"""
LASER_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Laser from Bottom\".
"""
LASER_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Wavy Line from Left\".
"""
LASER_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Laser from Lower Left\".
"""
LASER_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Laser from Lower Right\".
"""
LASER_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Laser from Right\".
"""
LASER_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Laser from Top\".
"""
LASER_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Laser from Upper Left\".
"""
LASER_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Laser from Upper Right\".
"""
MOVE_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Move from Bottom\".

use the fade effect \"Move from Bottom\".
"""
MOVE_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Move from Left\".

use the fade effect \"Move from Left\".
"""
MOVE_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Move from Lower Left\".

use the fade effect \"Move from Lower Left\".
"""
MOVE_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move from Lower Right\".

use the fade effect \"Move from Lower Right\".
"""
MOVE_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Move from Right\".

use the fade effect \"Move from Right\".
"""
MOVE_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Move from Top\".

use the fade effect \"Move from Top\".
"""
MOVE_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Move from Upper Left\".

use the fade effect \"Move from Upper Left\".
"""
MOVE_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move from Upper Right\".

use the fade effect \"Move from Upper Right\".
"""
MOVE_SHORT_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Move Short from Bottom\".
"""
MOVE_SHORT_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Move Short from Left\".
"""
MOVE_SHORT_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Move Short from Lower Left\".
"""
MOVE_SHORT_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move Short from Lower Right\".
"""
MOVE_SHORT_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Move Short from Right\".
"""
MOVE_SHORT_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Move Short from Top\".
"""
MOVE_SHORT_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Move Short from Upper Left\".
"""
MOVE_SHORT_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move Short from Upper Right\".
"""
MOVE_SHORT_TO_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Move Short to Bottom\".
"""
MOVE_SHORT_TO_LEFT: 'uno.Enum'
"""
use the animation effect \"Move Short to Left\".
"""
MOVE_SHORT_TO_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Move Short to Lower Left\".
"""
MOVE_SHORT_TO_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move Short to Lower Right\".
"""
MOVE_SHORT_TO_RIGHT: 'uno.Enum'
"""
use the animation effect \"Move Short to Right\".
"""
MOVE_SHORT_TO_TOP: 'uno.Enum'
"""
use the animation effect \"Move Short to Top\".
"""
MOVE_SHORT_TO_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Move Short to Upper Left\".
"""
MOVE_SHORT_TO_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move Short to Upper Right\".
"""
MOVE_TO_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Move to Bottom\".
"""
MOVE_TO_LEFT: 'uno.Enum'
"""
use the animation effect \"Move to Left\".
"""
MOVE_TO_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Move to Lower Left\".
"""
MOVE_TO_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move to Lower Right\".
"""
MOVE_TO_RIGHT: 'uno.Enum'
"""
use the animation effect \"Move to Right\".
"""
MOVE_TO_TOP: 'uno.Enum'
"""
use the animation effect \"Move to Top\".
"""
MOVE_TO_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Move to Upper Left\".
"""
MOVE_TO_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Move to Upper Right\".
"""
NONE: 'uno.Enum'
"""
use no animation effects.

use no fade effects.

No action is performed on click.
"""
OPEN_HORIZONTAL: 'uno.Enum'
"""
use the animation effect \"Open Horizontal\".

use the fade effect \"Open Horizontal\".
"""
OPEN_VERTICAL: 'uno.Enum'
"""
use the animation effect \"Open Vertical\".

use the fade effect \"Open Vertical\".
"""
PATH: 'uno.Enum'
"""
use the animation effect \"Path\".
"""
RANDOM: 'uno.Enum'
"""
use the animation effect \"Random\".

use the fade effect \"Random\".
"""
SPIRALIN_LEFT: 'uno.Enum'
"""
use the animation effect \"Spiral Inward Left\".

use the fade effect \"Spiral Inward Left\".
"""
SPIRALIN_RIGHT: 'uno.Enum'
"""
use the animation effect \"Spiral Inward Right\".

use the fade effect \"Spiral Inward Right\".
"""
SPIRALOUT_LEFT: 'uno.Enum'
"""
use the animation effect \"Spiral Outward Left\".

use the fade effect \"Spiral Outward Left\".
"""
SPIRALOUT_RIGHT: 'uno.Enum'
"""
use the animation effect \"Spiral Outward Right\".

use the fade effect \"Spiral Outward Right\".
"""
STRETCH_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Stretch From Bottom\".

use the fade effect \"Stretch from Bottom\".
"""
STRETCH_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Stretch From Left\".

use the fade effect \"Stretch from Left\".
"""
STRETCH_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Stretch From Lower Left\".
"""
STRETCH_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Stretch From Lower Right\".
"""
STRETCH_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Stretch From Right\".

use the fade effect \"Stretch from Right\".
"""
STRETCH_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Stretch From Top\".

use the fade effect \"Stretch from Top\".
"""
STRETCH_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Stretch From Upper Left\".
"""
STRETCH_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Stretch From Upper Right\".
"""
VERTICAL_CHECKERBOARD: 'uno.Enum'
"""
use the animation effect \"Vertical Checkerboard\".

use the fade effect \"Vertical Checkerboard\".
"""
VERTICAL_LINES: 'uno.Enum'
"""
use the animation effect \"Vertical Lines\".

use the fade effect \"Vertical Lines\".
"""
VERTICAL_ROTATE: 'uno.Enum'
"""
use the animation effect \"Vertical Rotate\".
"""
VERTICAL_STRETCH: 'uno.Enum'
"""
use the animation effect \"Vertical Stretch\".
"""
VERTICAL_STRIPES: 'uno.Enum'
"""
use the animation effect \"Vertical Stripes\".

use the fade effect \"Vertical Stripes\".
"""
WAVYLINE_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Wavy Line from Button\".

use the fade effect \"Wavy Line from Bottom\".
"""
WAVYLINE_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Wavy Line from Left\".

use the fade effect \"Wavy Line from Left\".
"""
WAVYLINE_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Wavy Line from Right\".

use the fade effect \"Wavy Line from Right\".
"""
WAVYLINE_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Wavy Line from Top\".

use the fade effect \"Wavy Line from Top\".
"""
ZOOM_IN: 'uno.Enum'
"""
use the animation effect \"Zoom In\".
"""
ZOOM_IN_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Zoom In From Bottom\".
"""
ZOOM_IN_FROM_CENTER: 'uno.Enum'
"""
use the animation effect \"Zoom In From Center\".
"""
ZOOM_IN_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Zoom In From Left\".
"""
ZOOM_IN_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Zoom In From Lower Left\".
"""
ZOOM_IN_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Zoom In From Lower Right\".
"""
ZOOM_IN_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Zoom In From Right\".
"""
ZOOM_IN_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Zoom In From Top\".
"""
ZOOM_IN_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Zoom In From Upper Left\".
"""
ZOOM_IN_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Zoom In From Upper Right\".
"""
ZOOM_IN_SMALL: 'uno.Enum'
"""
use the animation effect \"Zoom In Small\".
"""
ZOOM_IN_SPIRAL: 'uno.Enum'
"""
use the animation effect \"Zoom In Spiral\".
"""
ZOOM_OUT: 'uno.Enum'
"""
use the animation effect \"Zoom Out\".
"""
ZOOM_OUT_FROM_BOTTOM: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Bottom\".
"""
ZOOM_OUT_FROM_CENTER: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Center\".
"""
ZOOM_OUT_FROM_LEFT: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Left\".
"""
ZOOM_OUT_FROM_LOWERLEFT: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Lower Left\".
"""
ZOOM_OUT_FROM_LOWERRIGHT: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Lower Right\".
"""
ZOOM_OUT_FROM_RIGHT: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Right\".
"""
ZOOM_OUT_FROM_TOP: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Top\".
"""
ZOOM_OUT_FROM_UPPERLEFT: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Upper Left\".
"""
ZOOM_OUT_FROM_UPPERRIGHT: 'uno.Enum'
"""
use the animation effect \"Zoom Out From Upper Right\".
"""
ZOOM_OUT_SMALL: 'uno.Enum'
"""
use the animation effect \"Zoom Out Small\".
"""
ZOOM_OUT_SPIRAL: 'uno.Enum'
"""
use the animation effect \"Zoom Out Spiral\".
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ...uno.runtime_exception import RuntimeException as RuntimeException_d7390ced
from ...uno.x_interface import XInterface as XInterface_8f010a43

class InvalidDNDOperationException(RuntimeException_d7390ced):
    """
    Exception Class

    This exception is thrown by various methods in the datatransfer.dnd package.
    
    It is usually thrown to indicate that the target in question is unable to undertake the requested operation at the present time, since the underlying Drag and Drop system is not in the appropriate state.

    See Also:
        `API InvalidDNDOperationException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1InvalidDNDOperationException.html>`_
    """

    typeName: Literal['com.sun.star.datatransfer.dnd.InvalidDNDOperationException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['InvalidDNDOperationException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from ..frame.x_model import XModel as XModel_7a6e095c
if typing.TYPE_CHECKING:
    from .x_text import XText as XText_690408ca

class XTextDocument(XModel_7a6e095c):
    """
    is the main interface of a text document.

    See Also:
        `API XTextDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextDocument.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XTextDocument']

    def getText(self) -> 'XText_690408ca':
        """
        This text does not contain texts in TextFrames, or cells of TextTables etc. directly. These are accessible from the contents via X...Supplier (e.g. XTextTablesSupplier).
        """
    def reformat(self) -> None:
        """
        reformats the contents of the document.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These values define parts of bibliographic data.

They are used to create a bibliography in a text document.

Depending on the type of the data some of the fields will usually be left empty.

**since**

    LibreOffice 7.3

See Also:
    `API BibliographyDataField <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html>`_
"""
IDENTIFIER: Literal[0]
"""
This field contains a unique identifier for the bibliographic data.
"""
BIBILIOGRAPHIC_TYPE: Literal[1]
"""
This field contains the type of the bibliographic reference.

It is of the type BibliographyDataType.
"""
ADDRESS: Literal[2]
"""
This field contains the address of the publisher.
"""
ANNOTE: Literal[3]
"""
This field contains an annotation.
"""
AUTHOR: Literal[4]
"""
This field contains the name(s) of the author(s)
"""
BOOKTITLE: Literal[5]
"""
This field contains the title of the book.
"""
CHAPTER: Literal[6]
"""
This field contains the name or number of the chapter.
"""
EDITION: Literal[7]
"""
This field contains the number or name of the edition.
"""
EDITOR: Literal[8]
"""
This field contains the name(s) of the editor(s)
"""
HOWPUBLISHED: Literal[9]
"""
This field contains a description of the type of the publishing.
"""
INSTITUTION: Literal[10]
"""
This field contains the name of the institution where the publishing was created.
"""
JOURNAL: Literal[11]
"""
This field contains the name of the journal.
"""
MONTH: Literal[12]
"""
This field contains number or name of the month of the publishing.
"""
NOTE: Literal[13]
"""
This field contains a note.
"""
NUMBER: Literal[14]
"""
This field contains the number of the publishing.
"""
ORGANIZATIONS: Literal[15]
"""
This field contains the name of the organizations where the publishing was created.
"""
PAGES: Literal[16]
"""
This field contains the number(s) of the page(s) of the reference into a publishing.
"""
PUBLISHER: Literal[17]
"""
This field contains the name of the publisher.
"""
SCHOOL: Literal[18]
"""
This field contains the name of the university or school where the publishing was created.
"""
SERIES: Literal[19]
"""
This field contains the series of the publishing.
"""
TITLE: Literal[20]
"""
This field contains the title of the publishing.
"""
REPORT_TYPE: Literal[21]
"""
This field contains a description of the type of the report.
"""
VOLUME: Literal[22]
"""
This field contains the volume of the publishing.
"""
YEAR: Literal[23]
"""
This field contains the year when the publishing was created.
"""
URL: Literal[24]
"""
This field contains URL of the publishing.
"""
CUSTOM1: Literal[25]
"""
This field contains user defined data.
"""
CUSTOM2: Literal[26]
"""
This field contains user defined data.
"""
CUSTOM3: Literal[27]
"""
This field contains user defined data.
"""
CUSTOM4: Literal[28]
"""
This field contains user defined data.
"""
CUSTOM5: Literal[29]
"""
This field contains user defined data.
"""
ISBN: Literal[30]
"""
This field contains the ISBN data of the publishing.
"""
LOCAL_URL: Literal[31]
"""
This field contains a local copy of the publishing.

**since**

    LibreOffice 7.3
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XErrorHandler(XInterface_8f010a43):
    """
    is the basic interface for SAX error handlers.
    
    If a SAX application needs to implement customized error handling, it must implement this interface and then register an instance with the SAX parser using the parser's XParser.setErrorhandler() method. The parser will then report all errors and warnings through this interface.
    
    This interface is a slight adaptation of the Java interface org.xml.sax.ErrorHandler. In IDL, no exception can be passed as an argument, so an any serves as the container. The type of the exception is SAXParseException or an instance of a derived class.

    See Also:
        `API XErrorHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XErrorHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XErrorHandler']

    def error(self, aSAXParseException: object) -> None:
        """
        receives notification of a recoverable error.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def fatalError(self, aSAXParseException: object) -> None:
        """
        receives notification of a non-recoverable error.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def warning(self, aSAXParseException: object) -> None:
        """
        receives notification of a warning.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..container.container_event import ContainerEvent as ContainerEvent_ea50e70
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ConfigurationEvent(ContainerEvent_ea50e70):
    """
    Struct Class

    this event is broadcasted by a configuration manager whenever the state of user interface element has changed.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ConfigurationEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ui_1_1ConfigurationEvent.html>`_
    """
    typeName: Literal['com.sun.star.ui.ConfigurationEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Accessor: typing.Optional[object] = ..., Element: typing.Optional[object] = ..., ReplacedElement: typing.Optional[object] = ..., ResourceURL: typing.Optional[str] = ..., aInfo: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Accessor (object, optional): Accessor value.
            Element (object, optional): Element value.
            ReplacedElement (object, optional): ReplacedElement value.
            ResourceURL (str, optional): ResourceURL value.
            aInfo (object, optional): aInfo value.
        """


    @property
    def ResourceURL(self) -> str:
        """
        contains the resource URL of the user interface element or a configuration manager, which has been changed, inserted or replaced.
        """


    @property
    def aInfo(self) -> object:
        """
        contains additional information about this configuration event.
        
        The type depends on the specific implementation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.wrapper
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..sax.x_document_handler import XDocumentHandler as XDocumentHandler_9b90e28
    from .xxml_element_wrapper import XXMLElementWrapper as XXMLElementWrapper_66c0107c

class XXMLDocumentWrapper(XInterface_8f010a43):
    """
    Interface of XML Document Wrapper.
    
    When converting SAX events into a DOM tree, this interface is used to manipulate the DOM data in UNO perspective.
    
    Every language has its own methods to manipulate its native DOM data structure, this interface provides a common method set which each language have to implement.
    
    In another word, this interface wraps language dependent methods, then other component can manipulate DOM data through UNO methods.

    See Also:
        `API XXMLDocumentWrapper <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1wrapper_1_1XXMLDocumentWrapper.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.wrapper.XXMLDocumentWrapper']

    def clearUselessData(self, node: 'XXMLElementWrapper_66c0107c', reservedDescendants: 'typing.Tuple[XXMLElementWrapper_66c0107c, ...]', stopAtNode: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Clears all useless element in a branch of the DOM tree along the tree order.
        """
    def collapse(self, node: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Collapses a tree path.
        
        Each element in the ancestor path of the node will be checked, if this element is empty, then deletes it.
        """
    def generateSAXEvents(self, handler: 'XDocumentHandler_9b90e28', saxEventKeeperHandler: 'XDocumentHandler_9b90e28', startNode: 'XXMLElementWrapper_66c0107c', endNode: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Converts a part of the DOM tree into SAX events.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def getCurrentElement(self) -> 'XXMLElementWrapper_66c0107c':
        """
        Gets the current element.
        """
    def getNodeName(self, node: 'XXMLElementWrapper_66c0107c') -> str:
        """
        Gets the name of the element.
        """
    def getTree(self, handler: 'XDocumentHandler_9b90e28') -> None:
        """
        Converts the whole DOM tree into a SAX event stream.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def isCurrent(self, node: 'XXMLElementWrapper_66c0107c') -> bool:
        """
        Checks whether an element is the current element.
        """
    def isCurrentElementEmpty(self) -> bool:
        """
        Checks whether the current element is empty.
        """
    def rebuildIDLink(self, node: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Rebuild the ID attribute in the branch starting from the particular element.
        """
    def removeCurrentElement(self) -> None:
        """
        Removes the current element.
        
        When the current element is removed, then its parent element becomes the new current element.
        """
    def setCurrentElement(self, element: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Sets the current element.
        
        When the current element is replaced outside of this interface, then uses this method can update the current element pointer.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from .x_path_settings import XPathSettings as XPathSettings_bc930bfc


class thePathSettings(XPathSettings_bc930bfc):
    """
    Singleton Class

    Supports read/write access and listener for the paths properties that the Office uses.
    
    The property names of the Office paths/directories are an exactly match to the configuration entries found in the file (org/openoffice/Office/Common.xml).
    This service supports the usage of path variables to define paths that a relative to other office or system directories. See PathSubstitution
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) PathSettings service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API thePathSettings <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1util_1_1thePathSettings.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal


class CommandGroup(object):
    """
    Const

    provides information about a supported command
    
    **since**
    
        OOo 2.0

    See Also:
        `API CommandGroup <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1frame_1_1CommandGroup.html>`_
    """
    INTERNAL: Literal[0]
    """
    specifies internal commands.
    """
    APPLICATION: Literal[1]
    """
    specifies application based commands.
    """
    VIEW: Literal[2]
    """
    specifies view specific commands.
    """
    DOCUMENT: Literal[3]
    """
    specifies document specific commands.
    """
    EDIT: Literal[4]
    """
    specifies edit specific commands.
    """
    MACRO: Literal[5]
    """
    specifies commands used by the built-in Basic.
    """
    OPTIONS: Literal[6]
    """
    specifies commands to change options.
    """
    MATH: Literal[7]
    """
    specifies math specific commands.
    """
    NAVIGATOR: Literal[8]
    """
    specifies navigate commands.
    """
    INSERT: Literal[9]
    """
    specifies insert commands.
    """
    FORMAT: Literal[10]
    """
    specifies commands that are related to formats.
    """
    TEMPLATE: Literal[11]
    """
    specifies commands that are related to templates.
    """
    TEXT: Literal[12]
    """
    specifies text specific commands.
    """
    FRAME: Literal[13]
    """
    specifies frame specific commands.
    """
    GRAPHIC: Literal[14]
    """
    specifies commands that are related to graphical data.
    """
    TABLE: Literal[15]
    """
    specifies commands that are related to tables.
    """
    ENUMERATION: Literal[16]
    """
    specifies commands that are related to bullets and numbering.
    """
    DATA: Literal[17]
    """
    specifies commands that are related to data.
    """
    SPECIAL: Literal[18]
    """
    specifies special commands.
    """
    IMAGE: Literal[19]
    """
    specifies commands that are related to images.
    """
    CHART: Literal[20]
    """
    specifies chart specific commands.
    """
    EXPLORER: Literal[21]
    """
    specifies explorer specific commands.
    """
    CONNECTOR: Literal[22]
    """
    specifies commands that are related to connectors.
    """
    MODIFY: Literal[23]
    """
    specifies commands that are related to modifications.
    """
    DRAWING: Literal[24]
    """
    specifies commands that are related to drawing.
    """
    CONTROLS: Literal[25]
    """
    specifies commands that are related to controls.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class DispatchResultEvent(EventObject_a3d70b03):
    """
    Struct Class

    contains the result of the dispatch action, if State is set to SUCCESS
    
    The type of the result is dispatch action dependent. The member State can be set to one of the values defined in DispatchResultState. If State is set to DispatchResultState.FAILURE, Result may specify the reason (or is empty). The type is also dispatch action dependent. If State is set to DispatchResultState.DONTKNOW, Result is empty.

    See Also:
        `API DispatchResultEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1DispatchResultEvent.html>`_
    """
    typeName: Literal['com.sun.star.frame.DispatchResultEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., State: typing.Optional[int] = ..., Result: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            State (int, optional): State value.
            Result (object, optional): Result value.
        """


    @property
    def State(self) -> int:
        """
        describes state of dispatch
        """


    @property
    def Result(self) -> object:
        """
        describes result for given State
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4
if typing.TYPE_CHECKING:
    from ..container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7
    from .text_animation_direction import TextAnimationDirection as TextAnimationDirection_6c5510da
    from .text_animation_kind import TextAnimationKind as TextAnimationKind_1c710ebf
    from .text_fit_to_size_type import TextFitToSizeType as TextFitToSizeType_1bd90ebc
    from .text_horizontal_adjust import TextHorizontalAdjust as TextHorizontalAdjust_4cf9102e
    from .text_vertical_adjust import TextVerticalAdjust as TextVerticalAdjust_2c160f3e
    from ..text.writing_mode import WritingMode as WritingMode_a6dd0b36
    from ..text.x_text_columns import XTextColumns as XTextColumns_b17f0bab

class TextProperties(CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, ParagraphPropertiesAsian_6e8c10e8, ParagraphPropertiesComplex_91de11d4):
    """
    Service Class

    This is a set of properties to describe the style for rendering the text area inside a shape.
    
    **since**
    
        LibreOffice 7.2

    See Also:
        `API TextProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1TextProperties.html>`_
    """
    @property
    def IsNumbering(self) -> bool:
        """
        If this is TRUE, numbering is ON for the text of this Shape.
        """
    @property
    def NumberingRules(self) -> 'XIndexReplace_feed0dd7':
        """
        describes the numbering levels.
        
        The different rules accessible with this com.sun.star.container.XIndexReplace interface are sequences of property values as described in the service com.sun.star.style.NumberingRule.
        """
    @property
    def TextAnimationAmount(self) -> int:
        """
        This is the number of pixels the text is moved in each animation step.
        """
    @property
    def TextAnimationCount(self) -> int:
        """
        This number defines how many times the text animation is repeated.
        
        If this is set to zero, the repeat is endless.
        """
    @property
    def TextAnimationDelay(self) -> int:
        """
        This is the delay in thousandths of a second between each of the animation steps.
        """
    @property
    def TextAnimationDirection(self) -> 'TextAnimationDirection_6c5510da':
        """
        This enumeration defines the direction in which the text moves.
        """
    @property
    def TextAnimationKind(self) -> 'TextAnimationKind_1c710ebf':
        """
        This value defines the type of animation.
        """
    @property
    def TextAnimationStartInside(self) -> bool:
        """
        If this value is TRUE, the text is visible at the start of the animation.
        """
    @property
    def TextAnimationStopInside(self) -> bool:
        """
        If this value is TRUE, the text is visible at the end of the animation.
        """
    @property
    def TextAutoGrowHeight(self) -> bool:
        """
        If this value is TRUE, the height of the Shape is automatically expanded/shrunk when text is added to or removed from the Shape.
        """
    @property
    def TextAutoGrowWidth(self) -> bool:
        """
        If this value is TRUE, the width of the Shape is automatically expanded/shrunk when text is added to or removed from the Shape.
        """
    @property
    def TextColumns(self) -> 'XTextColumns_b17f0bab':
        """
        Column layout properties for the text.
        
        **since**
        
            LibreOffice 7.2
        """
    @property
    def TextContourFrame(self) -> bool:
        """
        If this value is TRUE, the left edge of every line of text is aligned with the left edge of this Shape.
        """
    @property
    def TextFitToSize(self) -> 'TextFitToSizeType_1bd90ebc':
        """
        With this set to a value other than NONE, the text inside of the Shape is stretched or scaled to fit into the Shape.
        """
    @property
    def TextHorizontalAdjust(self) -> 'TextHorizontalAdjust_4cf9102e':
        """
        adjusts the horizontal position of the text inside of the Shape.
        """
    @property
    def TextLeftDistance(self) -> int:
        """
        This is the distance from the left edge of the Shape to the left edge of the text.
        
        This is only useful if Text.TextHorizontalAdjust is BLOCK or STRETCH or if Text.TextFitSize is TRUE.
        """
    @property
    def TextLowerDistance(self) -> int:
        """
        This is the distance from the lower edge of the Shape to the lower edge of the text.
        
        This is only useful if Text.TextVerticalAdjust is BLOCK or if Text.TextFitSize is TRUE.
        """
    @property
    def TextMaximumFrameHeight(self) -> int:
        """
        with this property you can set the maximum height for a shape with text.
        
        On edit, the auto grow feature will not grow the object higher than the value of this property.
        """
    @property
    def TextMaximumFrameWidth(self) -> int:
        """
        with this property you can set the maximum width for a shape with text.
        
        On edit, the auto grow feature will not grow the objects wider than the value of this property.
        """
    @property
    def TextMinimumFrameHeight(self) -> int:
        """
        with this property you can set the minimum height for a shape with text.
        
        On edit, the auto grow feature will not shrink the objects height smaller than the value of this property.
        """
    @property
    def TextMinimumFrameWidth(self) -> int:
        """
        with this property you can set the minimum width for a shape with text.
        
        On edit, the auto grow feature will not shrink the object width smaller than the value of this property.
        """
    @property
    def TextRightDistance(self) -> int:
        """
        This is the distance from the right edge of the Shape to the right edge of the text.
        
        This is only useful if Text.TextHorizontalAdjust is BLOCK or STRETCH or if Text.TextFitSize is TRUE.
        """
    @property
    def TextUpperDistance(self) -> int:
        """
        This is the distance from the upper edge of the Shape to the upper edge of the text.
        
        This is only useful if Text.TextVerticalAdjust is BLOCK or if Text.TextFitSize is TRUE.
        """
    @property
    def TextVerticalAdjust(self) -> 'TextVerticalAdjust_2c160f3e':
        """
        adjusts the vertical position of the text inside of the Shape.
        """
    @property
    def TextWritingMode(self) -> 'WritingMode_a6dd0b36':
        """
        This value selects the writing mode for the text.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .dictionary_event import DictionaryEvent as DictionaryEvent_3ae00f8d


class DictionaryListEvent(EventObject_a3d70b03):
    """
    Struct Class

    structure representing a dictionary-list event.
    
    This structure is used by the dictionary-list to inform its listeners about certain events. Since the dictionary-list is able to collect several single events before broadcasting them to its listeners the integer argument may be a combination (logical or) of several event types. If more specific information about the events is requested by a listener, a sequence of all dictionary-list events since the last broadcasting will be supplied. Otherwise, that list will be empty.

    See Also:
        `API DictionaryListEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryListEvent.html>`_
    """
    typeName: Literal['com.sun.star.linguistic2.DictionaryListEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., aDictionaryEvents: typing.Optional[typing.Tuple[DictionaryEvent_3ae00f8d, ...]] = ..., nCondensedEvent: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            aDictionaryEvents (typing.Tuple[DictionaryEvent, ...], optional): aDictionaryEvents value.
            nCondensedEvent (int, optional): nCondensedEvent value.
        """


    @property
    def aDictionaryEvents(self) -> typing.Tuple[DictionaryEvent_3ae00f8d, ...]:
        """
        list of accumulated dictionary events.
        
        It will be empty if all com.sun.star.linguistic2.XDictionaryListEventListener are satisfied with the condensed representation of the com.sun.star.linguistic2.DictionaryListEvent.nCondensedEvent().
        """


    @property
    def nCondensedEvent(self) -> int:
        """
        the combined type of the accumulated events.
        
        The value can be the combination of multiple com.sun.star.linguistic2.DictionaryListEventFlags by applying the logical OR to them.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XProgressHandler(XInterface_8f010a43):
    """
    Handle a tasks notification that it has made some progress.

    See Also:
        `API XProgressHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XProgressHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XProgressHandler']

    def pop(self) -> None:
        """
        The task notifies the handler that it has finished its current activity.
        """
    def push(self, Status: object) -> None:
        """
        The task notifies the handler that it has started some new activity (possibly a sub-activity of another activity already making progress; therefore, these notifications behave in a stack-like manner).
        """
    def update(self, Status: object) -> None:
        """
        The task notifies the handler that its current activity is making progress.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_chart_document import XChartDocument as XChartDocument_d3630ca3
from ..drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier_1a030eab
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222

class ChartDocument(UserDefinedAttributesSupplier_9fbe1222, XPropertySet_bc180bfa, XChartDocument_d3630ca3, XDrawPageSupplier_1a030eab):
    """
    Service Class

    is the service for a chart document.
    
    A chart document consists of a reference to the data source, the diagram and some additional elements like a main title, a sub-title or a legend.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartDocument.html>`_
    """
    @property
    def HasLegend(self) -> bool:
        """
        determines if the legend is shown or hidden.
        """
    @property
    def HasMainTitle(self) -> bool:
        """
        determines if the main title is shown or hidden.
        """
    @property
    def HasSubTitle(self) -> bool:
        """
        determines if the subtitle is shown or hidden.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb.application
from typing_extensions import Literal
"""
Const

specifies the possible continuations when copying a table row via a CopyTableWizard failed.

See Also:
    `API CopyTableContinuation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1CopyTableContinuation.html>`_
"""
Proceed: Literal[0]
"""
indicates the error should be ignored, and copying should be continued.
"""
CallNextHandler: Literal[1]
"""
is used to indicate the next registered XCopyTableListener should be called.
"""
Cancel: Literal[2]
"""
cancels the whole copying process
"""
AskUser: Literal[3]
"""
asks the user how the handle the error.

The user can choose between ignoring the error and canceling the copy operation.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XLibraryContainerExport(XInterface_8f010a43):
    """
    Extension of XLibraryContainer to provide functionality to store a library to a location represented by a URL.

    See Also:
        `API XLibraryContainerExport <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XLibraryContainerExport.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XLibraryContainerExport']

    def exportLibrary(self, Name: str, URL: str, Handler: 'XInteractionHandler_bf80e51') -> None:
        """
        Exports a library specified by Name to the location specified by the passed URL string.
        
        An interaction handler can be passed to be used for internal ucb operations. Exceptions not processed by this handler will be passed as com.sun.star.uno.Exception. If this parameter is null this applies to all exceptions thrown by ucb.
        
        If a library with the this name doesn't exist a com.sun.star.container.NoSuchElementException is thrown.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_alter_view import XAlterView as XAlterView_a42a0b07
from .x_rename import XRename as XRename_848c09cc

class View(XPropertySet_bc180bfa, XAlterView_a42a0b07, XRename_848c09cc):
    """
    Service Class

    is used to specify views on data.
    
    A view object is only used for creation and deletion. Inspecting the command of a view is normally not supported.
    
    If a view is going to be added to a database, the view must have a unique name within the view and the table container, as it can be used like a table.  Note:  After addition, both the containers for views and the container for tables must contain an element for the view.

    See Also:
        `API View <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1View.html>`_
    """
    @property
    def CatalogName(self) -> str:
        """
        is the name of the views catalog, may be empty.
        """
    @property
    def CheckOption(self) -> int:
        """
        indicates if a check option should be used for the view.
        """
    @property
    def Command(self) -> str:
        """
        is the command for creating the view.
        
        This is typically a SQL Select-Statement.
        
        This property might be empty when a backend does not support retrieving the current SQL command of a view. However, if the View supports altering its command via the XAlterView interface, then it's required to also provide the current SQL command in the Command property.
        """
    @property
    def Name(self) -> str:
        """
        is the name of the view.
        """
    @property
    def SchemaName(self) -> str:
        """
        is the name of the view's schema, may be empty.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924

class DatasourceAdministrationDialog(XPropertySet_bc180bfa, XInitialization_d46c0cca, XExecutableDialog_450f0fa1):
    """
    Service Class

    provides a user interface for administrating the system wide registered data sources.
    
    Here, system wide registered means registered on the (one and only) instance of the com.sun.star.sdb.DatabaseContext service.

    See Also:
        `API DatasourceAdministrationDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatasourceAdministrationDialog.html>`_
    """
    @property
    def ParentWindow(self) -> 'XWindow_713b0924':
        """
        parent window to use for the administration dialog
        
        This property can't be set while the dialog is being displayed.
        """
    @property
    def Title(self) -> str:
        """
        the title of the (dialog) window
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal


class AnimationNodeType(object):
    """
    Const

    This constants defines a type for an animation node.
    
    It can be used to quickly identify semantic blocks inside an animation hierarchy.
    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API AnimationNodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationNodeType.html>`_
    """
    CUSTOM: Literal[0]
    """
    Defines a custom time node.
    """
    PAR: Literal[1]
    """
    Defines a parallel time container.
    """
    SEQ: Literal[2]
    """
    Defines a sequence time container.
    """
    ITERATE: Literal[3]
    """
    Defines an iterate time container.
    """
    ANIMATE: Literal[4]
    """
    Defines a generic attribute animation.
    """
    SET: Literal[5]
    """
    Defines a simple mean of just setting the value of an attribute for a specified duration.
    """
    ANIMATEMOTION: Literal[6]
    """
    Defines a move animation along a path.
    """
    ANIMATECOLOR: Literal[7]
    """
    Defines an animation of a color attribute.
    """
    ANIMATETRANSFORM: Literal[8]
    """
    Defines an animation of a transformation attribute.
    """
    TRANSITIONFILTER: Literal[9]
    """
    Defines an animation of a filter behavior.
    """
    AUDIO: Literal[10]
    """
    Defines an audio effect.
    """
    COMMAND: Literal[11]
    """
    Defines a command effect.
    """
    ANIMATEPHYSICS: Literal[12]
    """
    Defines a physics animation.
    
    **since**
    
        LibreOffice 7.1
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal


class UIElementType(object):
    """
    Const

    determine the type of a user interface element which is controlled by a layout manager.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UIElementType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1UIElementType.html>`_
    """
    UNKNOWN: Literal[0]
    """
    unknown user interface element type, which can be used as a wildcard to specify all types.
    """
    MENUBAR: Literal[1]
    """
    specifies a menu bar.
    """
    POPUPMENU: Literal[2]
    """
    specifies a pop-up menu.
    """
    TOOLBAR: Literal[3]
    """
    specifies a toolbar.
    """
    STATUSBAR: Literal[4]
    """
    specifies a statusbar.
    """
    FLOATINGWINDOW: Literal[5]
    """
    specifies a floating window, which can also be docked.
    """
    PROGRESSBAR: Literal[6]
    """
    specifies a floating window, which can also be docked.
    """
    TOOLPANEL: Literal[7]
    """
    specifies a tool panel
    """
    DOCKINGWINDOW: Literal[7]
    """
    specifies a window that can be docked.
    """
    COUNT: Literal[8]
    """
    specifies the number of constants.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
import typing
from .x_resource_factory import XResourceFactory as XResourceFactory_b3561268
if typing.TYPE_CHECKING:
    from ...frame.x_controller import XController as XController_b00e0b8f

class BasicPaneFactory(XResourceFactory_b3561268):
    """
    Service Class

    The BasicPaneFactory is a resource factory that provides the panes used by the Draw and Impress applications.
    
    This factory provides the center, left, and right pane. For the left pane there are two URLS, private:resource/floater/LeftImpressPane and private:resource/floater/LeftDrawPane, one for Impress, the other for Draw. The center pane and the right pane have the URLs private:resource/floater/CenterPane and private:resource/floater/RightPane respectively.
    
    This factory is typically created indirectly by registering it in the configuration and have the XModuleController create it on demand.

    See Also:
        `API BasicPaneFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1BasicPaneFactory.html>`_
    """
    def create(self, xController: 'XController_b00e0b8f') -> None:
        """
        Give the controller to new instances so that they have access to the drawing framework controllers.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from .x_replace_descriptor import XReplaceDescriptor as XReplaceDescriptor_fd510df9
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XPropertyReplace(XReplaceDescriptor_fd510df9):
    """
    makes it possible to search and replace properties.

    See Also:
        `API XPropertyReplace <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XPropertyReplace.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XPropertyReplace']

    def getReplaceAttributes(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        """
    def getSearchAttributes(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        """
    def getValueSearch(self) -> bool:
        """
        provides the information if specific property values are searched, or just the existence of the specified properties.
        """
    def setReplaceAttributes(self, aSearchAttribs: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        sets the properties to replace the found occurrences.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setSearchAttributes(self, aSearchAttribs: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        sets the properties to search for.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setValueSearch(self, bValueSearch: bool) -> None:
        """
        specifies if specific property values are searched, or just the existence of the specified properties.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

CTL script type constants for layout engine, returned by XScriptTypeDetector.getCTLScriptType()

**since**

    OOo 1.1.2

See Also:
    `API CTLScriptType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1CTLScriptType.html>`_
"""
CTL_UNKNOWN: Literal[0]
"""
For CTL scripts OOo currently does not support or could not handle.
"""
CTL_HEBREW: Literal[1]
"""
For Hebrew script.
"""
CTL_ARABIC: Literal[2]
"""
For Arabic script.
"""
CTL_THAI: Literal[3]
"""
For Thai script.
"""
CTL_INDIC: Literal[4]
"""
For Indic script (including Devanagari, Tamil, Telugu and Gujarati script)
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal


class AnimationRepeat(object):
    """
    Const

    This are the possible repeat modes for animations.
    
    These constants determine how the [0,1] parameter range of the animation is driven through, thus defining the possible repeat modes.
    
    **since**
    
        OOo 2.0

    See Also:
        `API AnimationRepeat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1AnimationRepeat.html>`_
    """
    ONE_SHOT: Literal[0]
    """
    The [0,1] parameter range is swept through exactly once.
    
    The [0,1] parameter range is swept through exactly once, starting with 0 and ending with 1.
    """
    ONE_SHOT_PINGPONG: Literal[1]
    """
    The [0,1] parameter range is swept through exactly twice.
    
    The [0,1] parameter range is swept through exactly twice, starting with 0, going to 1, and going back to 0. When plotting the value over time, this yields a triangle curve.
    """
    PINGPONG: Literal[2]
    """
    The [0,1] parameter range is swept through infinitely.
    
    The [0,1] parameter range is swept through infinitely, starting with 0, going to 1, and going back to 0, and then starting again. When plotting the value over time, this yields a repeated triangle curve.
    """
    REPEAT: Literal[3]
    """
    The [0,1] parameter range is swept through infinitely.
    
    The [0,1] parameter range is swept through infinitely, starting with 0, going to 1, and starting with 0 again. When plotting the value over time, this yields a repeated saw-tooth curve.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
from abc import ABC

class XPublished(ABC):
    """
    Reflects the âpublishedâ status of a UNOIDL entity.
    
    This interface is intended to be supported by objects that also support com.sun.star.reflection.XTypeDescription. (This interface could have been made an optional sub-interface of com.sun.star.reflection.XTypeDescription, but is instead kept independent for reasons of backwards compatibility.)
    
    For the various kinds of UNOIDL entities that are represented by objects supporting com.sun.star.reflection.XTypeDescription and its subtypes, this optional interface should be supported as follows:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPublished <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XPublished.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XPublished']

    def isPublished(self) -> bool:
        """
        Returns the âpublishedâ status of a UNOIDL entity.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XFilter(XInterface_8f010a43):
    """
    interface to filter documents
    
    This interface will be used by service ImportFilter or ExportFilter to support loading/saving of documents in different formats. The target/source of such filter operations must be known before filtering will be started. (see XImporter and XExporter too) Otherwise this interface can't work right.

    See Also:
        `API XFilter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XFilter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XFilter']

    def cancel(self) -> None:
        """
        cancel the process.
        """
    def filter(self, aDescriptor: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> bool:
        """
        filter the document.
        
        The given MediaDescriptor holds all necessary information about the document.
        
        Don't hold hard references to the descriptor items. You must copy needed information! Otherwise we couldn't destroy (for example) an existing input stream!
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration.backend
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_backend import XBackend as XBackend_6ce81076
    from .x_layer import XLayer as XLayer_4cd50fcb

class XLayerImporter(XInterface_8f010a43):
    """
    allows importing a layer into a Backend
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XLayerImporter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerImporter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.configuration.backend.XLayerImporter']

    def getTargetBackend(self) -> 'XBackend_6ce81076':
        """
        gets the target backend for importing.
        """
    def importLayer(self, aLayer: 'XLayer_4cd50fcb') -> None:
        """
        Imports the layer given into the backend.
        
        This method imports data for the current entity of the backend.

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NullPointerException: ``NullPointerException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def importLayerForEntity(self, aLayer: 'XLayer_4cd50fcb', aEntity: str) -> None:
        """
        Imports the layer given into the backend for a given entity.
        
        This method imports data for the current entity of the backend.

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NullPointerException: ``NullPointerException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setTargetBackend(self, aBackend: 'XBackend_6ce81076') -> None:
        """
        sets the target backend for importing.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration
from .configuration_provider import ConfigurationProvider as ConfigurationProvider_cc8d1323
from ..lang.x_localizable import XLocalizable as XLocalizable_aee00b64
from ..util.x_flushable import XFlushable as XFlushable_9a420ab4
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81

class DefaultProvider(ConfigurationProvider_cc8d1323, XLocalizable_aee00b64, XFlushable_9a420ab4, XRefreshable_b0d60b81):
    """
    Service Class

    is a ConfigurationProvider, that is the default ConfigurationProvider for its com.sun.star.uno.XComponentContext.
    
    This object is accessible as singleton theDefaultProvider
    
    .
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DefaultProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1DefaultProvider.html>`_
    """
    @property
    def EnableAsync(self) -> bool:
        """
        Property to enable/disable asynchronous write-back from in-memory cache to backend(s)
        
        **since**
        
            OOo 2.0
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb.application
# Libre Office Version: 7.3
from typing_extensions import Literal
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing
from ...sdbc.x_result_set import XResultSet as XResultSet_98e30aa7


class CopyTableRowEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies an event happening while copying table data between databases.
    
    Whenever this event is fired to an XCopyTableListener, com.sun.star.lang.EventObject.Source contains the wizard instance which actually does the copying.

    See Also:
        `API CopyTableRowEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sdb_1_1application_1_1CopyTableRowEvent.html>`_
    """
    typeName: Literal['com.sun.star.sdb.application.CopyTableRowEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., SourceData: typing.Optional[XResultSet_98e30aa7] = ..., Error: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            SourceData (XResultSet, optional): SourceData value.
            Error (object, optional): Error value.
        """


    @property
    def SourceData(self) -> XResultSet_98e30aa7:
        """
        contains the result set which is being copied by the wizard currently.
        """


    @property
    def Error(self) -> object:
        """
        denotes the error which happened while copying the data.
        
        Usually, this contains an instance of com.sun.star.sdbc.SQLException.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

Constants designating the formula language used with XFormulaOpCodeMapper methods.

**since**

    LibreOffice 5.3

See Also:
    `API FormulaLanguage <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html>`_
"""
ODFF: Literal[0]
"""
Function names and operators as defined by the OASIS OpenDocument Format (ODF) Formula specification (ODFF aka OpenFormula).
"""
ODF_11: Literal[1]
"""
Function names and operators as used in ODF documents prior to the ODFF specification, up to ODF v1.1.
"""
ENGLISH: Literal[2]
"""
Function names and operators as used in the English language user interface.
"""
NATIVE: Literal[3]
"""
Function names and operators as used in the current native language user interface.
"""
XL_ENGLISH: Literal[4]
"""
Function names and operators as used in the English version of Excel.

This formula language is also used in VBA formulas.
"""
OOXML: Literal[5]
"""
Function names and operators as used in OOXML.

**since**

    LibreOffice 4.2
"""
API: Literal[6]
"""
Function names and operators as used with XFunctionAccess and other API context.

Names are mostly identical to ENGLISH and ODF_11, but while ENGLISH names can be adapted to UI needs and ODF_11 has to stay error compatible, the API names strive to stay compatible but may get corrected in case of errors. Earlier versions than LibreOffice 5.3 always used ODF_11 in API context.

**since**

    LibreOffice 5.3
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class TimeIncrement(object):
    """
    Struct Class

    A TimeIncrement describes how tickmarks are positioned on the scale of a date-time axis.
    
    **since**
    
        OOo 3.4

    See Also:
        `API TimeIncrement <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart_1_1TimeIncrement.html>`_
    """
    typeName: Literal['com.sun.star.chart.TimeIncrement']

    def __init__(self, MajorTimeInterval: typing.Optional[object] = ..., MinorTimeInterval: typing.Optional[object] = ..., TimeResolution: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            MajorTimeInterval (object, optional): MajorTimeInterval value.
            MinorTimeInterval (object, optional): MinorTimeInterval value.
            TimeResolution (object, optional): TimeResolution value.
        """


    @property
    def MajorTimeInterval(self) -> object:
        """
        if the any contains a struct of type com.sun.star.chart.TimeInterval this is used as a fixed distance value for the major tickmarks.
        
        Otherwise, if the any is empty or contains an incompatible type, the distance between major tickmarks is calculated automatically by the application.
        """


    @property
    def MinorTimeInterval(self) -> object:
        """
        if the any contains a struct of type com.sun.star.chart.TimeInterval this is used as a fixed distance value for the minor tickmarks.
        
        Otherwise, if the any is empty or contains an incompatible type, the distance between minor tickmarks is calculated automatically by the application.
        """


    @property
    def TimeResolution(self) -> object:
        """
        if the any contains a constant of type com.sun.star.chart.TimeUnit this is the smallest time unit that is displayed on the date-time axis.
        
        Otherwise, if the any is empty or contains an incompatible type, the resolution is chosen automatically by the application.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from typing_extensions import Literal


class SQLFilterOperator(object):
    """
    Const

    These constants are used to specify the filter operator which should be applied when creating a filter with the method XSingleSelectQueryComposer.setStructuredFilter().

    See Also:
        `API SQLFilterOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1SQLFilterOperator.html>`_
    """
    EQUAL: Literal[1]
    """
    equal to
    """
    NOT_EQUAL: Literal[2]
    """
    not equal to
    """
    LESS: Literal[3]
    """
    less than
    """
    GREATER: Literal[4]
    """
    greater than
    """
    LESS_EQUAL: Literal[5]
    """
    less or equal than
    """
    GREATER_EQUAL: Literal[6]
    """
    greater or equal than
    """
    LIKE: Literal[7]
    """
    like
    """
    NOT_LIKE: Literal[8]
    """
    not like
    """
    SQLNULL: Literal[9]
    """
    is null
    """
    NOT_SQLNULL: Literal[10]
    """
    is not null
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.table
from typing_extensions import Literal
"""
Const


See Also:
    `API BorderLineStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1table_1_1BorderLineStyle.html>`_
"""
NONE: Literal[32767]
"""
No border line.
"""
SOLID: Literal[0]
"""
Solid border line.
"""
DOTTED: Literal[1]
"""
Dotted border line.
"""
DASHED: Literal[2]
"""
Dashed border line.
"""
DOUBLE: Literal[3]
"""
Double border line.

Widths of the lines and the gap are all equal, and vary equally with the total width.
"""
THINTHICK_SMALLGAP: Literal[4]
"""
Double border line with a thin line outside and a thick line inside separated by a small gap.
"""
THINTHICK_MEDIUMGAP: Literal[5]
"""
Double border line with a thin line outside and a thick line inside separated by a medium gap.
"""
THINTHICK_LARGEGAP: Literal[6]
"""
Double border line with a thin line outside and a thick line inside separated by a large gap.
"""
THICKTHIN_SMALLGAP: Literal[7]
"""
Double border line with a thick line outside and a thin line inside separated by a small gap.
"""
THICKTHIN_MEDIUMGAP: Literal[8]
"""
Double border line with a thick line outside and a thin line inside separated by a medium gap.
"""
THICKTHIN_LARGEGAP: Literal[9]
"""
Double border line with a thick line outside and a thin line inside separated by a large gap.
"""
EMBOSSED: Literal[10]
"""
3D embossed border line.
"""
ENGRAVED: Literal[11]
"""
3D engraved border line.
"""
OUTSET: Literal[12]
"""
Outset border line.
"""
INSET: Literal[13]
"""
Inset border line.
"""
FINE_DASHED: Literal[14]
"""
Finely dashed border line.
"""
DOUBLE_THIN: Literal[15]
"""
Double border line consisting of two fixed thin lines separated by a variable gap.
"""
DASH_DOT: Literal[16]
"""
Line consisting of a repetition of one dash and one dot.
"""
DASH_DOT_DOT: Literal[17]
"""
Line consisting of a repetition of one dash and 2 dots.
"""
BORDER_LINE_STYLE_MAX: Literal[17]
"""
Maximum valid border line style value.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal
"""
Const

defines the color space that is used for interpolation.

This does not change how colors are interpreted but how to interpolate from one color to another.

See Also:
    `API AnimationColorSpace <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationColorSpace.html>`_
"""
RGB: Literal[0]
"""
defines that the RGB color space is used for interpolation.
"""
HSL: Literal[1]
"""
defines that the HSL color space is used for interpolation.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XCellRangeFormula(XInterface_8f010a43):
    """
    allows to get and set cell contents (values, text or formulas) for a cell range.
    
    The outer sequence represents the rows and the inner sequence the columns of the array.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XCellRangeFormula <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeFormula.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XCellRangeFormula']

    def getFormulaArray(self) -> 'typing.Tuple[typing.Tuple[str, ...], ...]':
        """
        gets an array from the contents of the cell range.
        
        Each element of the result contains the same string that would be returned by com.sun.star.table.XCell.getFormula() for the corresponding cell.
        """
    def setFormulaArray(self, aArray: 'typing.Tuple[typing.Tuple[str, ...], ...]') -> None:
        """
        fills the cell range with values from an array.
        
        The size of the array must be the same as the size of the cell range. Each element of the array is interpreted the same way as the argument to a com.sun.star.table.XCell.setFormula() call for the corresponding cell.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.runtime
import typing
from .x_form_operations import XFormOperations as XFormOperations_4a450ffe
if typing.TYPE_CHECKING:
    from ..x_form import XForm as XForm_684408a8
    from .x_form_controller import XFormController as XFormController_4a570ffe

class FormOperations(XFormOperations_4a450ffe):
    """
    Service Class

    encapsulates operations on a database form which has a UI representation, and is interacting with the user.
    
    **since**
    
        OOo 2.2

    See Also:
        `API FormOperations <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1runtime_1_1FormOperations.html>`_
    """
    def createWithForm(self, Form: 'XForm_684408a8') -> None:
        """
        creates a FormOperations instance which works on a com.sun.star.form.component.DataForm instance.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createWithFormController(self, Controller: 'XFormController_4a570ffe') -> None:
        """
        creates a FormOperations instance which works on a com.sun.star.form.FormController instance.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from .x_property_control_observer import XPropertyControlObserver as XPropertyControlObserver_cc6d132a
if typing.TYPE_CHECKING:
    from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2

class XPropertyControlContext(XPropertyControlObserver_cc6d132a):
    """
    specifies the interface of the context of an XPropertyControl.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XPropertyControlContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControlContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XPropertyControlContext']

    def activateNextControl(self, CurrentControl: 'XPropertyControl_3f260fe2') -> None:
        """
        instructs the XPropertyControlContext to active the next control
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from .x_model2 import XModel2 as XModel2_83fc098e
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XModel3(XModel2_83fc098e):
    """
    extends interface XModel2 with optimised read access getArgs().

    See Also:
        `API XModel3 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XModel3.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XModel3']

    def getArgs2(self, requestedArgs: 'typing.Tuple[str, ...]') -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Provides optimised read access (so we don't need to fetch expensive properties that we are not interested in) on currently representation of the com.sun.star.document.MediaDescriptor of this model which describes the model and its state.
        
        Returns only the selected args.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class SecurityOperationStatus(Enum):
    """
    Enum

    

    See Also:
        `API SecurityOperationStatus <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dc>`_
    """

    ASSERTION: 'uno.Enum'
    """
    """
    CERT_HAS_EXPIRED: 'uno.Enum'
    """
    """
    CERT_ISSUER_FAILED: 'uno.Enum'
    """
    """
    CERT_NOT_FOUND: 'uno.Enum'
    """
    """
    CERT_NOT_YET_VALID: 'uno.Enum'
    """
    """
    CERT_REVOKED: 'uno.Enum'
    """
    """
    CERT_VERIFY_FAILED: 'uno.Enum'
    """
    """
    CRYPTO_FAILED: 'uno.Enum'
    """
    """
    DATA_NOT_MATCH: 'uno.Enum'
    """
    """
    DISABLED: 'uno.Enum'
    """
    """
    DSIG_INVALID_REFERENCE: 'uno.Enum'
    """
    """
    DSIG_NO_REFERENCES: 'uno.Enum'
    """
    """
    ENGINE_FAILED: 'uno.Enum'
    """
    The following constants are derived from XMLSec error definitions, as following:
    
    XMLSEC_ERRORS_R_XMLSEC_FAILED XMLSEC_ERRORS_R_MALLOC_FAILED XMLSEC_ERRORS_R_STRDUP_FAILED XMLSEC_ERRORS_R_CRYPTO_FAILED XMLSEC_ERRORS_R_XML_FAILED XMLSEC_ERRORS_R_XSLT_FAILED XMLSEC_ERRORS_R_IO_FAILED XMLSEC_ERRORS_R_DISABLED XMLSEC_ERRORS_R_NOT_IMPLEMENTED XMLSEC_ERRORS_R_INVALID_SIZE XMLSEC_ERRORS_R_INVALID_DATA XMLSEC_ERRORS_R_INVALID_RESULT XMLSEC_ERRORS_R_INVALID_TYPE XMLSEC_ERRORS_R_INVALID_OPERATION XMLSEC_ERRORS_R_INVALID_STATUS XMLSEC_ERRORS_R_INVALID_FORMAT XMLSEC_ERRORS_R_DATA_NOT_MATCH XMLSEC_ERRORS_R_INVALID_NODE XMLSEC_ERRORS_R_INVALID_NODE_CONTENT XMLSEC_ERRORS_R_INVALID_NODE_ATTRIBUTE XMLSEC_ERRORS_R_MISSING_NODE_ATTRIBUTE XMLSEC_ERRORS_R_NODE_ALREADY_PRESENT XMLSEC_ERRORS_R_UNEXPECTED_NODE XMLSEC_ERRORS_R_NODE_NOT_FOUND XMLSEC_ERRORS_R_INVALID_TRANSFORM XMLSEC_ERRORS_R_INVALID_TRANSFORM_KEY XMLSEC_ERRORS_R_INVALID_URI_TYPE XMLSEC_ERRORS_R_TRANSFORM_SAME_DOCUMENT_REQUIRED XMLSEC_ERRORS_R_TRANSFORM_DISABLED XMLSEC_ERRORS_R_INVALID_KEY_DATA XMLSEC_ERRORS_R_KEY_DATA_NOT_FOUND XMLSEC_ERRORS_R_KEY_DATA_ALREADY_EXIST XMLSEC_ERRORS_R_INVALID_KEY_DATA_SIZE XMLSEC_ERRORS_R_KEY_NOT_FOUND XMLSEC_ERRORS_R_KEYDATA_DISABLED XMLSEC_ERRORS_R_MAX_RETRIEVALS_LEVEL XMLSEC_ERRORS_R_MAX_RETRIEVAL_TYPE_MISMATCH XMLSEC_ERRORS_R_MAX_ENCKEY_LEVEL XMLSEC_ERRORS_R_CERT_VERIFY_FAILED XMLSEC_ERRORS_R_CERT_NOT_FOUND XMLSEC_ERRORS_R_CERT_REVOKED XMLSEC_ERRORS_R_CERT_ISSUER_FAILED XMLSEC_ERRORS_R_CERT_NOT_YET_VALID XMLSEC_ERRORS_R_CERT_HAS_EXPIRED XMLSEC_ERRORS_R_DSIG_NO_REFERENCES XMLSEC_ERRORS_R_DSIG_INVALID_REFERENCE XMLSEC_ERRORS_R_ASSERTION XMLSEC_ERRORS_MAX_NUMBER
    """
    INVALID_DATA: 'uno.Enum'
    """
    """
    INVALID_FORMAT: 'uno.Enum'
    """
    """
    INVALID_KEY_DATA: 'uno.Enum'
    """
    """
    INVALID_KEY_DATA_SIZE: 'uno.Enum'
    """
    """
    INVALID_NODE: 'uno.Enum'
    """
    """
    INVALID_NODE_ATTRIBUTE: 'uno.Enum'
    """
    """
    INVALID_NODE_CONTENT: 'uno.Enum'
    """
    """
    INVALID_OPERATION: 'uno.Enum'
    """
    """
    INVALID_RESULT: 'uno.Enum'
    """
    """
    INVALID_SIZE: 'uno.Enum'
    """
    """
    INVALID_STATUS: 'uno.Enum'
    """
    """
    INVALID_TRANSFORM: 'uno.Enum'
    """
    """
    INVALID_TRANSFORM_KEY: 'uno.Enum'
    """
    """
    INVALID_TYPE: 'uno.Enum'
    """
    """
    INVALID_URI_TYPE: 'uno.Enum'
    """
    """
    IO_FAILED: 'uno.Enum'
    """
    """
    KEYDATA_DISABLED: 'uno.Enum'
    """
    """
    KEY_DATA_ALREADY_EXIST: 'uno.Enum'
    """
    """
    KEY_DATA_NOT_FOUND: 'uno.Enum'
    """
    """
    KEY_NOT_FOUND: 'uno.Enum'
    """
    """
    MALLOC_FAILED: 'uno.Enum'
    """
    """
    MAX_ENCKEY_LEVEL: 'uno.Enum'
    """
    """
    MAX_RETRIEVALS_LEVEL: 'uno.Enum'
    """
    """
    MAX_RETRIEVAL_TYPE_MISMATCH: 'uno.Enum'
    """
    """
    MISSING_NODE_ATTRIBUTE: 'uno.Enum'
    """
    """
    NODE_ALREADY_PRESENT: 'uno.Enum'
    """
    """
    NODE_NOT_FOUND: 'uno.Enum'
    """
    """
    NOT_IMPLEMENTED: 'uno.Enum'
    """
    """
    OPERATION_SUCCEEDED: 'uno.Enum'
    """
    """
    RUNTIMEERROR_FAILED: 'uno.Enum'
    """
    """
    STRDUP_FAILED: 'uno.Enum'
    """
    """
    TRANSFORM_DISABLED: 'uno.Enum'
    """
    """
    TRANSFORM_SAME_DOCUMENT_REQUIRED: 'uno.Enum'
    """
    """
    UNEXPECTED_NODE: 'uno.Enum'
    """
    """
    UNKNOWN: 'uno.Enum'
    """
    """
    XML_FAILED: 'uno.Enum'
    """
    """
    XSLT_FAILED: 'uno.Enum'
    """
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from .date import Date as Date_60040844

class NumberFormatSettings(XPropertySet_bc180bfa):
    """
    Service Class

    specifies the settings for number formatting.

    See Also:
        `API NumberFormatSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings.html>`_
    """
    @property
    def NoZero(self) -> bool:
        """
        is set to indicate that a zero value should be formatted as an empty string.
        """
    @property
    def NullDate(self) -> 'Date_60040844':
        """
        specifies the date which is represented by the value 0.
        
        The most common value for this is 12/30/1899.
        """
    @property
    def StandardDecimals(self) -> int:
        """
        specifies the maximum number of decimals used for the standard number format (\"General\").
        """
    @property
    def TwoDigitDateStart(self) -> int:
        """
        specifies the first year to be generated from a two-digit year input.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class GeneralFunction(Enum):
    """
    Enum

    

    See Also:
        `API GeneralFunction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758d>`_
    """

    AUTO: 'uno.Enum'
    """
    specifies the use of a user-defined list.
    
    function is determined automatically.
    """
    AVERAGE: 'uno.Enum'
    """
    average of all numerical values is calculated.
    """
    COUNT: 'uno.Enum'
    """
    all values, including non-numerical values, are counted.
    """
    COUNTNUMS: 'uno.Enum'
    """
    numerical values are counted.
    """
    MAX: 'uno.Enum'
    """
    maximum value of all numerical values is calculated.
    """
    MIN: 'uno.Enum'
    """
    minimum value of all numerical values is calculated.
    """
    NONE: 'uno.Enum'
    """
    no cells are moved.
    
    sheet is not linked.
    
    new values are used without changes.
    
    nothing is calculated.
    
    nothing is imported.
    
    no condition is specified.
    """
    PRODUCT: 'uno.Enum'
    """
    product of all numerical values is calculated.
    """
    STDEV: 'uno.Enum'
    """
    standard deviation is calculated based on a sample.
    """
    STDEVP: 'uno.Enum'
    """
    standard deviation is calculated based on the entire population.
    """
    SUM: 'uno.Enum'
    """
    sum of all numerical values is calculated.
    """
    VAR: 'uno.Enum'
    """
    variance is calculated based on a sample.
    """
    VARP: 'uno.Enum'
    """
    variance is calculated based on the entire population.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Property(object):
    """
    Struct Class

    This structure describes a property.
    
    There are three types of properties:

    See Also:
        `API Property <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1Property.html>`_
    """
    typeName: Literal['com.sun.star.beans.Property']

    def __init__(self, Name: typing.Optional[str] = ..., Handle: typing.Optional[int] = ..., Type: typing.Optional[object] = ..., Attributes: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Handle (int, optional): Handle value.
            Type (object, optional): Type value.
            Attributes (int, optional): Attributes value.
        """


    @property
    def Name(self) -> str:
        """
        specifies the name of the property.
        
        The name is unique within an XPropertySet. Upper and lower case are distinguished.
        """


    @property
    def Handle(self) -> int:
        """
        contains an implementation-specific handle for the property.
        
        It may be -1 if the implementation has no handle. You can use this handle to get values from the XFastPropertySet.
        """


    @property
    def Type(self) -> object:
        """
        contains an object that identifies the declared type for the property.
        
        If the property has multiple types or the type is not known, but not an any, then void must be returned.
        """


    @property
    def Attributes(self) -> int:
        """
        This field may contain zero or more constants of the PropertyAttribute constants group.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.table
import typing
from ..util.sort_descriptor2 import SortDescriptor2 as SortDescriptor2_d7270cbf
if typing.TYPE_CHECKING:
    from .table_sort_field import TableSortField as TableSortField_d3860c84

class TableSortDescriptor2(SortDescriptor2_d7270cbf):
    """
    Service Class

    specifies properties which describe sorting of fields (rows or columns) in a table.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TableSortDescriptor2 <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor2.html>`_
    """
    @property
    def SortFields(self) -> 'typing.Tuple[TableSortField_d3860c84, ...]':
        """
        specifies a list of individual sort fields.
        
        Each entry specifies properties that state the row/column to be sorted and how that should be done.
        """
    @property
    def IsSortColumns(self) -> bool:
        """
        specifies if the columns or rows are to be sorted.
        """
    @property
    def MaxSortFieldsCount(self) -> int:
        """
        contains the maximum number of sort fields the descriptor can hold.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from ..container.x_child import XChild as XChild_a6390b07
from .x_queries_supplier import XQueriesSupplier as XQueriesSupplier_d4920ccb
from .xsql_query_composer_factory import XSQLQueryComposerFactory as XSQLQueryComposerFactory_42300fbf
from ..sdbc.connection import Connection as Connection_98fe0ab4
from ..sdbcx.database_definition import DatabaseDefinition as DatabaseDefinition_9d00e3a

class DatabaseAccessConnection(Connection_98fe0ab4, DatabaseDefinition_9d00e3a, XChild_a6390b07, XQueriesSupplier_d4920ccb, XSQLQueryComposerFactory_42300fbf):
    """
    Service Class

    specifies a component, which supplies and stores additional information related to a certain database connection, such as, DatabaseQueries, FormDocuments, and ReportDocuments.
    
    Objects for data definition are supplied as well, for instance, Tables, Views, etc.
    
    Implements the service com.sun.star.sdbc.Connection. It is possible to open more than one connection at the same time, but the method com.sun.star.sdb.DatabaseAccessConnection.dispose() will close only one of these connections. You have to close all connections in order to close the connection to the database.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DatabaseAccessConnection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccessConnection.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text.textfield
import typing
from ..text_field import TextField as TextField_90260a56
if typing.TYPE_CHECKING:
    from ...util.date import Date as Date_60040844
    from ...util.date_time import DateTime as DateTime_84de09d3

class Annotation(TextField_90260a56):
    """
    Service Class

    specifies service of an annotation text field.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API Annotation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Annotation.html>`_
    """
    @property
    def Author(self) -> str:
        """
        contains the name of the author of the annotation.
        """
    @property
    def Content(self) -> str:
        """
        contains the annotation's content
        """
    @property
    def Date(self) -> 'Date_60040844':
        """
        contains the creation date.
        """
    @property
    def DateTimeValue(self) -> 'DateTime_84de09d3':
        """
        contains the creation date.
        """
    @property
    def Initials(self) -> str:
        """
        contains the initials of the author of the annotation.
        
        **since**
        
            LibreOffice 4.0
        """
    @property
    def Name(self) -> str:
        """
        contains the name of the annotation.
        
        **since**
        
            LibreOffice 4.0
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script.browse
# Libre Office Version: 7.3
from .x_browse_node_factory import XBrowseNodeFactory as XBrowseNodeFactory_8e541185


class theBrowseNodeFactory(XBrowseNodeFactory_8e541185):
    """
    Singleton Class

    The one and only BrowseNodeFactory.
    
    To get the singleton call getValueByName on the component context
    
    **since**
    
        OOo 2.0

    See Also:
        `API theBrowseNodeFactory <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1script_1_1browse_1_1theBrowseNodeFactory.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ItemListEvent(EventObject_a3d70b03):
    """
    Struct Class

    is the event broadcasted by a XListItems implementation for changes in its item list.

    See Also:
        `API ItemListEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1ItemListEvent.html>`_
    """
    typeName: Literal['com.sun.star.awt.ItemListEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., ItemPosition: typing.Optional[int] = ..., ItemText: typing.Optional[object] = ..., ItemImageURL: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            ItemPosition (int, optional): ItemPosition value.
            ItemText (object, optional): ItemText value.
            ItemImageURL (object, optional): ItemImageURL value.
        """


    @property
    def ItemPosition(self) -> int:
        """
        specifies the position of the item which is affected by the event
        
        In case the event is not related to a single item, but to the complete list, the value of this member is undefined.
        """


    @property
    def ItemText(self) -> object:
        """
        the text of the item.
        
        If the event being notified did not touch the text of an item, this member is empty. For instance, upon invocation of XItemList.setItemImage(), only ItemImageURL will be set, and ItemText will be empty.
        """


    @property
    def ItemImageURL(self) -> object:
        """
        the URL of the image of the item
        
        If the event being notified did not touch the image of an item, this member is empty. For instance, upon invocation of XItemList.setItemText(), only ItemText will be set, and ItemImageURL will be empty.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.beans
from typing_extensions import Literal
"""
Const

These constants are used to specify concepts of the introspection which apply to properties and to the methods which represent attributes.

This list is not necessarily complete; new constants may be added.

See Also:
    `API PropertyConcept <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans_1_1PropertyConcept.html>`_
"""
ALL: Literal[-1]
"""
This value is used to query for all properties.

See XIntrospectionAccess.getProperty() and XIntrospectionAccess.getProperties()
"""
DANGEROUS: Literal[1]
"""
specifies that the change or retrieval of this property directly by the user can result in an unstable state (deadlock, application crash, security hole, etc.)
"""
PROPERTYSET: Literal[2]
"""
specifies all properties which are reachable by XPropertySet, XFastPropertySet or XMultiPropertySet.
"""
ATTRIBUTES: Literal[4]
"""
specifies all properties which are actually attributes of interfaces.
"""
METHODS: Literal[8]
"""
specifies all properties which are represented by getter or setter methods.

These methods have the signature type get...(), void set...() or boolean is...().
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c

class ParametersRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    an error specifying the lack of parameters values
    
    Usually thrown if someone tries to execute an SQL statement containing parameters which can't be filled by the executing instance.

    See Also:
        `API ParametersRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdb_1_1ParametersRequest.html>`_
    """

    typeName: Literal['com.sun.star.sdb.ParametersRequest']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., Classification: typing.Optional[InteractionClassification_6c4d10e7] = ..., Parameters: typing.Optional[XIndexAccess_f0910d6d] = ..., Connection: typing.Optional[XConnection_a36a0b0c] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Parameters (XIndexAccess, optional): Parameters value.
            Connection (XConnection, optional): Connection value.
        """
    @property
    def Parameters(self) -> XIndexAccess_f0910d6d:
        """
        is the list of parameters requested.
        
        The objects returned by the com.sun.star.container.XIndexAccess have to be property sets describing the respective parameter. For this, the objects have to support the service com.sun.star.sdbcx.Column.
        """

    @property
    def Connection(self) -> XConnection_a36a0b0c:
        """
        specifies the connection on which the statement is to be executed.
        
        Somebody handling the request could, e.g., use the connection for determining the identifier quote string, etc.
        """


__all__ = ['ParametersRequest']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XLoadable(XInterface_8f010a43):
    """
    offers a simple way to initialize a component or load it from a URL.
    
    In case an object supports the interface the object must be initialized with either initNew() or load() call before any usage. In case the object is already initialized the mentioned methods should throw DoubleInitializationException.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XLoadable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XLoadable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XLoadable']

    def initNew(self) -> None:
        """
        creates a component from scratch

        Raises:
            DoubleInitializationException: ``DoubleInitializationException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def load(self, lArguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        loads a component from a URL

        Raises:
            DoubleInitializationException: ``DoubleInitializationException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XCloseListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events when an object is called for closing
    
    Such close events are broadcasted by a XCloseBroadcaster if somewhere tries to close it by calling XCloseable.close(). Listener can:
    
    If an event com.sun.star.lang.XEventListener.disposing() occurred, nobody called XCloseable.close() on listened object before. Then it's not allowed to break this request - it must be accepted!

    See Also:
        `API XCloseListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XCloseListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XCloseListener']

    def notifyClosing(self, Source: 'EventObject_a3d70b03') -> None:
        """
        is called when the listened object is closed really
        
        Now the listened object is closed really. Listener has to accept that; should deregister himself and release all references to it. It's not allowed nor possible to disagree with that by throwing any exception.
        
        If the event com.sun.star.lang.XEventListener.disposing() occurred before it must be accepted too. There exist no chance for a disagreement any more.
        """
    def queryClosing(self, Source: 'EventObject_a3d70b03', GetsOwnership: bool) -> None:
        """
        is called when somewhere tries to close listened object
        
        Is called before XCloseListener.notifyClosing(). Listener has the chance to break that by throwing a CloseVetoException. This exception must be passed to the original caller of XCloseable.close() without any interaction.
        
        The parameter GetsOwnership regulate who has to try to close the listened object again, if this listener disagree with the request by throwing the exception. If it's set to FALSE the original caller of XCloseable.close() will be the owner in every case. It's not allowed to call close() from this listener then. If it's set to TRUE this listener will be the new owner if he throw the exception, otherwise not! If his still running processes will be finished he must call close() on listened object again then.
        
        If this listener doesn't disagree with th close request it depends from his internal implementation if he deregister himself at the listened object. But normally this must be done in XCloseListener.notifyClosing().

        Raises:
            CloseVetoException: ``CloseVetoException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

specifies the type of a single condition in a filter descriptor.

This constants group extends the FilterOperator enum by additional filter operators.

**since**

    OOo 3.2

See Also:
    `API FilterOperator2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html>`_
"""
EMPTY: Literal[0]
"""
selects empty entries.
"""
NOT_EMPTY: Literal[1]
"""
selects non-empty entries.
"""
EQUAL: Literal[2]
"""
value has to be equal to the specified value.
"""
NOT_EQUAL: Literal[3]
"""
value must not be equal to the specified value.
"""
GREATER: Literal[4]
"""
value has to be greater than the specified value.
"""
GREATER_EQUAL: Literal[5]
"""
value has to be greater than or equal to the specified value.
"""
LESS: Literal[6]
"""
value has to be less than the specified value.
"""
LESS_EQUAL: Literal[7]
"""
value has to be less than or equal to the specified value.
"""
TOP_VALUES: Literal[8]
"""
selects a specified number of entries with the greatest values.
"""
TOP_PERCENT: Literal[9]
"""
selects a specified percentage of entries with the greatest values.
"""
BOTTOM_VALUES: Literal[10]
"""
selects a specified number of entries with the lowest values.
"""
BOTTOM_PERCENT: Literal[11]
"""
selects a specified percentage of entries with the lowest values.
"""
CONTAINS: Literal[12]
"""
selects contains entries.
"""
DOES_NOT_CONTAIN: Literal[13]
"""
selects does-not-contain entries.
"""
BEGINS_WITH: Literal[14]
"""
selects begins-with entries.
"""
DOES_NOT_BEGIN_WITH: Literal[15]
"""
selects does-not-begin-with entries.
"""
ENDS_WITH: Literal[16]
"""
selects ends-with entries.
"""
DOES_NOT_END_WITH: Literal[17]
"""
selects does-not-end-with entries.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
import typing
from ...awt.uno_control_list_box_model import UnoControlListBoxModel as UnoControlListBoxModel_2a3c0f1d
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_reset import XReset as XReset_71670917

class ListBox(UnoControlListBoxModel_2a3c0f1d, FormControlModel_e2990d22, XReset_71670917):
    """
    Service Class

    specifies a model for a control which allows to choose in a list of alternative values.

    See Also:
        `API ListBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ListBox.html>`_
    """
    @property
    def DefaultSelection(self) -> 'typing.Tuple[int, ...]':
        """
        contains the indexes of entries of the listbox, which should selected by default.
        
        This selection is used initially or for a reset.
        """
    @property
    def ListSource(self) -> 'typing.Tuple[str, ...]':
        """
        contains the values associated to the strings to be displayed (which are specified by com.sun.star.awt.UnoControlListBoxModel.StringItemList)
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XOrdinalSuffix(XInterface_8f010a43):
    """
    provides access to locale specific ordinal suffix systems.
    
    **since**
    
        OOo 2.2

    See Also:
        `API XOrdinalSuffix <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XOrdinalSuffix.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XOrdinalSuffix']

    def getOrdinalSuffix(self, nNumber: int, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        Returns all the possible ordinal suffixes for the number.
        
        This method will provide \"<b>st</b>\", \"<b>nd</b>\", \"<b>rd</b>\", \"<b>th</b>\" for an English locale, depending on the provided number. In some locales like French, Italian or Spanish it ca return several suffixes for one number.
        
        Examples: for the number '1', the values will be st in English, but er and re in French. All these values may depend on the underlying version of ICU.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from .x_sheet_cell_range import XSheetCellRange as XSheetCellRange_e09d0cdf

class XSheetCellCursor(XSheetCellRange_e09d0cdf):
    """
    provides advanced methods to control the position of a cursor in a spreadsheet.

    See Also:
        `API XSheetCellCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellCursor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XSheetCellCursor']

    def collapseToCurrentArray(self) -> None:
        """
        collapses the cursor into the range of the array formula to which it is currently pointing.
        
        To get the correct result, the top left cell of the original cursor must point to any cell containing an array formula. If not, the cursor is left unchanged.
        """
    def collapseToCurrentRegion(self) -> None:
        """
        expands the cursor into the region containing the cells to which it currently points.
        
        A region is a cell range bounded by empty cells.
        """
    def collapseToMergedArea(self) -> None:
        """
        expands the cursor to merged cell ranges.
        
        Expands the current cursor range in a way so that all merged cell ranges intersecting the current range will fit completely. If the cursor does not point to any range with merged cells, it is left unchanged.
        """
    def collapseToSize(self, nColumns: int, nRows: int) -> None:
        """
        changes the size of a cursor range.
        
        The top left cell of the cursor keeps unmodified.
        """
    def expandToEntireColumns(self) -> None:
        """
        expands the cursor to include the entire columns of the cells to which it is currently pointing.
        """
    def expandToEntireRows(self) -> None:
        """
        expands the cursor to include the entire rows of the cells to which it is currently pointing.
        """

